==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'An der Waardeschläif',
	'articles_meme_auteur' => 'All d’Artikelen vun dësem Auteur',
	'articles_off' => 'Blockéiert',
	'articles_publie' => 'Verëffentlecht',
	'articles_refuse' => 'Geläscht',
	'articles_tous' => 'Alleguer',
	'aucun_article_syndic' => 'Kee syndicéierten Artikel',
	'avis_echec_syndication_01' => 'D’Syndicatioun huet net funktionnéiert: de Backend ass nët ze dekodéieren oder en proposéiert guer keen Artikel.',
	'avis_echec_syndication_02' => 'D’Syndicatioun huet net funktionnéiert: onméiglech de Backend vun dëser Websäit ze erreechen.',
	'avis_site_introuvable' => 'D’Websäit ka net fonnt ginn',
	'avis_site_syndique_probleme' => 'Opgepasst: d’Syndicatioun vun dëser Websäit huet nët fonktionnéiert; de System ass elo zäitweis ënnerbrach. Kontrolléiert d’Adress vum Syndicatiouns-Fichier (<b>@url_syndic@</b>) a probéiert nach eng Kéier d’Informatiounen ze kréien.',
	'avis_sites_probleme_syndication' => 'Dës Websäit hun e Syndicatiouns-Problem',
	'avis_sites_syndiques_probleme' => 'Dës syndikéiert Websäiten hunn e Problem',

	// B
	'bouton_exporter' => 'Exportéieren',
	'bouton_importer' => 'Importéieren',
	'bouton_radio_modere_posteriori' => 'moderéiert "à posteriori"',
	'bouton_radio_modere_priori' => 'moderéiert "à priori"',
	'bouton_radio_non_syndication' => 'Keng Syndicatioun',
	'bouton_radio_syndication' => 'Syndicatioun:',

	// C
	'confirmer_purger_syndication' => 'Sidd dir sécher all syndicéiert Artikelen vun dëser Websäit ze läschen?',

	// E
	'entree_adresse_fichier_syndication' => 'Adress vum Fichier fir d’Syndicatioun:',
	'entree_adresse_site' => '<b>Adress vun der Websäit</b> [Obligatoresch]',
	'entree_description_site' => 'Beschreiwung vun der Websäit',
	'erreur_fichier_format_inconnu' => 'De Format vum Fichier @fichier@ gëtt net ugeholl.',
	'erreur_fichier_incorrect' => 'De Fichier ka net gelies ginn.',

	// F
	'form_prop_nom_site' => 'Numm vun der Websäit',

	// I
	'icone_article_syndic' => 'Syndicéierten Artikel',
	'icone_articles_syndic' => 'Syndicéiert Artikelen',
	'icone_controler_syndication' => 'Verëffentleche vun de syndicéierten Artikelen',
	'icone_modifier_site' => 'Dës Websäit änneren',
	'icone_referencer_nouveau_site' => 'Nei Websäit uginn',
	'icone_site_reference' => 'Verlinkte Websäiten',
	'icone_supprimer_article' => 'Dësen Artikel läschen',
	'icone_supprimer_articles' => 'Dës Artikele läschen',
	'icone_valider_article' => 'Dësen Artikel bestätegen',
	'icone_valider_articles' => 'Dës Artikele bestätegen',
	'icone_voir_sites_references' => 'Verlinkte Websäite weisen',
	'info_1_article_syndique' => '1 Artikel verlinkt',
	'info_1_site' => '1 Site',
	'info_1_site_importe' => '1 Websäit ass importéiert',
	'info_a_valider' => '[ze validéieren]',
	'info_aucun_article_syndique' => 'Keen Artikel verlinkt',
	'info_aucun_site' => 'Kee Site',
	'info_aucun_site_importe' => 'Et konnt kéng Websäit importéiert ginn',
	'info_bloquer' => 'blockéieren',
	'info_bloquer_lien' => 'Link blockéieren',
	'info_derniere_syndication' => 'Läscht Syndicatioun vun dëser Websäit den',
	'info_liens_syndiques_1' => 'Syndicéiert Linken',
	'info_liens_syndiques_2' => 'waarden ob eng Validatioun.',
	'info_nb_articles_syndiques' => '@nb@ verlinkten Artikelen',
	'info_nb_sites' => '@nb@ Websiten',
	'info_nb_sites_importes' => '@nb@ Websäite sinn importéiert ginn',
	'info_nom_site_2' => '<b>Numm vun ärer Websäit</b> [Obligatoresch]',
	'info_panne_site_syndique' => 'Pann vun der syndicéierter Websäit',
	'info_probleme_grave' => 'Problem mat',
	'info_question_proposer_site' => 'Wie kann eng Websäit virschloen?',
	'info_retablir_lien' => 'Dëse Link zerécksetzen',
	'info_site_attente' => 'Websäit waart op d’Bestätegung',
	'info_site_propose' => 'Websäit virgeschloen den:',
	'info_site_reference' => 'Verlinkte Websäit',
	'info_site_refuse' => 'Refuséiert Websäit',
	'info_site_syndique' => 'Dës Websäit ass syndicéiert...',
	'info_site_valider' => 'Websäiten ze bestätegen',
	'info_sites_referencer' => 'Eng Websäit verlinken',
	'info_sites_refuses' => 'Déi refuséiert Websäiten',
	'info_statut_site_1' => 'Dës Websäit ass:',
	'info_statut_site_2' => 'Verëffentlecht',
	'info_statut_site_3' => 'Proposéiert',
	'info_statut_site_4' => 'An der Dreckskëscht',
	'info_syndication' => 'Syndicatioun:',
	'info_syndication_articles' => 'Artikel(en)',
	'item_bloquer_liens_syndiques' => 'Déi syndicéiert Linken fir d’Bestätegung blockéieren',
	'item_gerer_annuaire_site_web' => 'Eng Link-Sammlung maachen',
	'item_non_bloquer_liens_syndiques' => 'D’Linken aus der Syndicatioun net blockéieren',
	'item_non_gerer_annuaire_site_web' => 'D’Link-Sammlung ausschalten',
	'item_non_utiliser_syndication' => 'Déi automatesch Syndicatioun ausschalten',
	'item_utiliser_syndication' => 'Déi automatesch Syndicatioun aschalten',

	// L
	'label_exporter_avec_mots_cles_1' => 'D’Schlësselwierder als Tags exportéieren',
	'label_exporter_id_parent' => 'D’Websäite vun der Rubrik exportéieren',
	'label_exporter_publie_seulement_1' => 'Nëmmen déi verëffentlecht Websäiten exportéieren',
	'label_fichier_import' => 'HTML-Fichier',
	'label_importer_les_tags_1' => 'Tags als Schlësselwierder importéieren',
	'label_importer_statut_publie_1' => 'Websäiten automatesch verëffentlechen',
	'lien_mise_a_jour_syndication' => 'Elo updaten',
	'lien_nouvelle_recuperation' => 'Eng nei Restauratioun vun den Daten probéieren',
	'lien_purger_syndication' => 'All déi syndicéiert Artikele läschen',

	// N
	'nombre_articles_syndic' => '@nb@ syndicéiert Artikelen',

	// S
	'statut_off' => 'Geläscht',
	'statut_prop' => 'An der Waardeschläif',
	'statut_publie' => 'Verëffentlecht',
	'syndic_choix_moderation' => 'Wat soll mat de nächste Linken vun dëser Websäit geschéien?',
	'syndic_choix_oublier' => 'Wat soll mat de Linken geschéien déi net méi am Syndicatiouns-Fichier sinn?',
	'syndic_choix_resume' => 'Verschidden Websäite verëffentlechen de kompletten Text vun den Artikelen. Wann deen do ass, wëll dir syndicéieren:',
	'syndic_lien_obsolete' => 'falsche Link',
	'syndic_option_miroir' => 'automatesch blockéieren',
	'syndic_option_oubli' => '(no @mois@ Méint) läschen',
	'syndic_option_resume_non' => 'de kompletten Inhalt vun den Artikelen (am HTML-Format)',
	'syndic_option_resume_oui' => 'en einfachen Résumé (am Text-Format)',
	'syndic_options' => 'Optiounen vun der Syndicatioun:',

	// T
	'texte_expliquer_export_bookmarks' => 'Dir kënnt eng Lëscht vun de Websäiten als HTML-Bookmarks exportéieren fir se dann an äre Browser oder en Online-Service ze importéieren',
	'texte_expliquer_import_bookmarks' => 'Dir kënnt eng Lëscht vu Websäiten am HTML-Bookmark-Format aus ärem Browser oder engem Online-Service importéieren.',
	'texte_liens_sites_syndiques' => 'D’Linken vun de syndicéierten Websäite kënnen fir d’éischt mol blockéiert ginn; d’Astellung hei drënner ass den Default fir déi nei syndicéiert Websäiten. Duerno kann een all Link eenzel deblockéieren, oder pro Websäit blockéieren oder nët.',
	'texte_messages_publics' => 'Öffentlëch Messagen vum Artikel:',
	'texte_non_fonction_referencement' => 'Dir wëllt villäicht dës automatesch Funktioun net aschalten a selwer d’Elementer vun der Websäit uginn...',
	'texte_referencement_automatique' => '<b>Automatescht Verlinke vun enger Websäit</b><br />Dir kënnt eng Websäit séier verlinken an dem der hei d’URL oder d’Adress vun sengem Syndicatiouns-Fichier agitt. SPIP kritt dann automatesch d’Informatiounen (Titel, Beschreiwung...).',
	'texte_referencement_automatique_verifier' => 'Kontrolléiert d’Informatiounen déi vun <tt>@url@</tt> koum sinn ier dër späichert.',
	'texte_syndication' => 'Et ass méiglech, wann eng Websäit dat erlaabt, automatesch d’Lëscht vun senge Neiegkeeten ze kréien. Schalt duerfir d’Syndicatioun an.<blockquote><i>Verschidde Hosting-Provideren verhënneren dës Prozedur; an deem Fall kënnt dir d’Syndicatioun net benotzen.</i></blockquote>',
	'titre_articles_syndiques' => 'Syndicéiert Artikelen vun dëser Websäit',
	'titre_dernier_article_syndique' => 'Läscht syndicéiert Artikelen',
	'titre_exporter_bookmarks' => 'Bookmarks exportéieren',
	'titre_importer_bookmarks' => 'Bookmarks importéieren',
	'titre_importer_exporter_bookmarks' => 'Bookmarks importéieren oder exportéieren',
	'titre_page_sites_tous' => 'Déi verlinkte Websäiten',
	'titre_referencement_sites' => 'Websäite verlinken a syndicéieren',
	'titre_site_numero' => 'WEBSÄIT NUMMER:',
	'titre_sites_proposes' => 'Virgeschloe Websäiten',
	'titre_sites_references_rubrique' => 'Verlinkte Websäiten an dëser Rubrik',
	'titre_sites_syndiques' => 'Syndicéiert Websäiten',
	'titre_sites_tous' => 'Déi verlinkte Websäiten',
	'titre_syndication' => 'Syndicatioun vun de Websäiten',
	'tout_voir' => 'All déi syndicéiert Artikele weisen',

	// U
	'un_article_syndic' => '1 syndicéierten Artikel'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'articles_dispo' => 'An der Waardeschläif',
	'articles_meme_auteur' => 'All d’Artikelen vun dësem Auteur',
	'articles_off' => 'Blockéiert',
	'articles_publie' => 'Verëffentlecht',
	'articles_refuse' => 'Geläscht',
	'articles_tous' => 'Alleguer',
	'aucun_article_syndic' => 'Kee syndicéierten Artikel',
	'avis_echec_syndication_01' => 'D’Syndicatioun huet net funktionnéiert: de Backend ass nët ze dekodéieren oder en proposéiert guer keen Artikel.',
	'avis_echec_syndication_02' => 'D’Syndicatioun huet net funktionnéiert: onméiglech de Backend vun dëser Websäit ze erreechen.',
	'avis_site_introuvable' => 'D’Websäit ka net fonnt ginn',
	'avis_site_syndique_probleme' => 'Opgepasst: d’Syndicatioun vun dëser Websäit huet nët fonktionnéiert; de System ass elo zäitweis ënnerbrach. Kontrolléiert d’Adress vum Syndicatiouns-Fichier (<b>@url_syndic@</b>) a probéiert nach eng Kéier d’Informatiounen ze kréien.',
	'avis_sites_probleme_syndication' => 'Dës Websäit hun e Syndicatiouns-Problem',
	'avis_sites_syndiques_probleme' => 'Dës syndikéiert Websäiten hunn e Problem',

	// B
	'bouton_exporter' => 'Exportéieren',
	'bouton_importer' => 'Importéieren',
	'bouton_radio_modere_posteriori' => 'moderéiert "à posteriori"',
	'bouton_radio_modere_priori' => 'moderéiert "à priori"',
	'bouton_radio_non_syndication' => 'Keng Syndicatioun',
	'bouton_radio_syndication' => 'Syndicatioun:',

	// C
	'confirmer_purger_syndication' => 'Sidd dir sécher all syndicéiert Artikelen vun dëser Websäit ze läschen?',

	// E
	'entree_adresse_fichier_syndication' => 'Adress vum Fichier fir d’Syndicatioun:',
	'entree_adresse_site' => '<b>Adress vun der Websäit</b> [Obligatoresch]',
	'entree_description_site' => 'Beschreiwung vun der Websäit',
	'erreur_fichier_format_inconnu' => 'De Format vum Fichier @fichier@ gëtt net ugeholl.',
	'erreur_fichier_incorrect' => 'De Fichier ka net gelies ginn.',

	// F
	'form_prop_nom_site' => 'Numm vun der Websäit',

	// I
	'icone_article_syndic' => 'Syndicéierten Artikel',
	'icone_articles_syndic' => 'Syndicéiert Artikelen',
	'icone_controler_syndication' => 'Verëffentleche vun de syndicéierten Artikelen',
	'icone_modifier_site' => 'Dës Websäit änneren',
	'icone_referencer_nouveau_site' => 'Nei Websäit uginn',
	'icone_site_reference' => 'Verlinkte Websäiten',
	'icone_supprimer_article' => 'Dësen Artikel läschen',
	'icone_supprimer_articles' => 'Dës Artikele läschen',
	'icone_valider_article' => 'Dësen Artikel bestätegen',
	'icone_valider_articles' => 'Dës Artikele bestätegen',
	'icone_voir_sites_references' => 'Verlinkte Websäite weisen',
	'info_1_article_syndique' => '1 Artikel verlinkt',
	'info_1_site' => '1 Site',
	'info_1_site_importe' => '1 Websäit ass importéiert',
	'info_a_valider' => '[ze validéieren]',
	'info_aucun_article_syndique' => 'Keen Artikel verlinkt',
	'info_aucun_site' => 'Kee Site',
	'info_aucun_site_importe' => 'Et konnt kéng Websäit importéiert ginn',
	'info_bloquer' => 'blockéieren',
	'info_bloquer_lien' => 'Link blockéieren',
	'info_derniere_syndication' => 'Läscht Syndicatioun vun dëser Websäit den',
	'info_liens_syndiques_1' => 'Syndicéiert Linken',
	'info_liens_syndiques_2' => 'waarden ob eng Validatioun.',
	'info_nb_articles_syndiques' => '@nb@ verlinkten Artikelen',
	'info_nb_sites' => '@nb@ Websiten',
	'info_nb_sites_importes' => '@nb@ Websäite sinn importéiert ginn',
	'info_nom_site_2' => '<b>Numm vun ärer Websäit</b> [Obligatoresch]',
	'info_panne_site_syndique' => 'Pann vun der syndicéierter Websäit',
	'info_probleme_grave' => 'Problem mat',
	'info_question_proposer_site' => 'Wie kann eng Websäit virschloen?',
	'info_retablir_lien' => 'Dëse Link zerécksetzen',
	'info_site_attente' => 'Websäit waart op d’Bestätegung',
	'info_site_propose' => 'Websäit virgeschloen den:',
	'info_site_reference' => 'Verlinkte Websäit',
	'info_site_refuse' => 'Refuséiert Websäit',
	'info_site_syndique' => 'Dës Websäit ass syndicéiert...',
	'info_site_valider' => 'Websäiten ze bestätegen',
	'info_sites_referencer' => 'Eng Websäit verlinken',
	'info_sites_refuses' => 'Déi refuséiert Websäiten',
	'info_statut_site_1' => 'Dës Websäit ass:',
	'info_statut_site_2' => 'Verëffentlecht',
	'info_statut_site_3' => 'Proposéiert',
	'info_statut_site_4' => 'An der Dreckskëscht',
	'info_syndication' => 'Syndicatioun:',
	'info_syndication_articles' => 'Artikel(en)',
	'item_bloquer_liens_syndiques' => 'Déi syndicéiert Linken fir d’Bestätegung blockéieren',
	'item_gerer_annuaire_site_web' => 'Eng Link-Sammlung maachen',
	'item_non_bloquer_liens_syndiques' => 'D’Linken aus der Syndicatioun net blockéieren',
	'item_non_gerer_annuaire_site_web' => 'D’Link-Sammlung ausschalten',
	'item_non_utiliser_syndication' => 'Déi automatesch Syndicatioun ausschalten',
	'item_utiliser_syndication' => 'Déi automatesch Syndicatioun aschalten',

	// L
	'label_exporter_avec_mots_cles_1' => 'D’Schlësselwierder als Tags exportéieren',
	'label_exporter_id_parent' => 'D’Websäite vun der Rubrik exportéieren',
	'label_exporter_publie_seulement_1' => 'Nëmmen déi verëffentlecht Websäiten exportéieren',
	'label_fichier_import' => 'HTML-Fichier',
	'label_importer_les_tags_1' => 'Tags als Schlësselwierder importéieren',
	'label_importer_statut_publie_1' => 'Websäiten automatesch verëffentlechen',
	'lien_mise_a_jour_syndication' => 'Elo updaten',
	'lien_nouvelle_recuperation' => 'Eng nei Restauratioun vun den Daten probéieren',
	'lien_purger_syndication' => 'All déi syndicéiert Artikele läschen',

	// N
	'nombre_articles_syndic' => '@nb@ syndicéiert Artikelen',

	// S
	'statut_off' => 'Geläscht',
	'statut_prop' => 'An der Waardeschläif',
	'statut_publie' => 'Verëffentlecht',
	'syndic_choix_moderation' => 'Wat soll mat de nächste Linken vun dëser Websäit geschéien?',
	'syndic_choix_oublier' => 'Wat soll mat de Linken geschéien déi net méi am Syndicatiouns-Fichier sinn?',
	'syndic_choix_resume' => 'Verschidden Websäite verëffentlechen de kompletten Text vun den Artikelen. Wann deen do ass, wëll dir syndicéieren:',
	'syndic_lien_obsolete' => 'falsche Link',
	'syndic_option_miroir' => 'automatesch blockéieren',
	'syndic_option_oubli' => '(no @mois@ Méint) läschen',
	'syndic_option_resume_non' => 'de kompletten Inhalt vun den Artikelen (am HTML-Format)',
	'syndic_option_resume_oui' => 'en einfachen Résumé (am Text-Format)',
	'syndic_options' => 'Optiounen vun der Syndicatioun:',

	// T
	'texte_expliquer_export_bookmarks' => 'Dir kënnt eng Lëscht vun de Websäiten als HTML-Bookmarks exportéieren fir se dann an äre Browser oder en Online-Service ze importéieren',
	'texte_expliquer_import_bookmarks' => 'Dir kënnt eng Lëscht vu Websäiten am HTML-Bookmark-Format aus ärem Browser oder engem Online-Service importéieren.',
	'texte_liens_sites_syndiques' => 'D’Linken vun de syndicéierten Websäite kënnen fir d’éischt mol blockéiert ginn; d’Astellung hei drënner ass den Default fir déi nei syndicéiert Websäiten. Duerno kann een all Link eenzel deblockéieren, oder pro Websäit blockéieren oder nët.',
	'texte_messages_publics' => 'Öffentlëch Messagen vum Artikel:',
	'texte_non_fonction_referencement' => 'Dir wëllt villäicht dës automatesch Funktioun net aschalten a selwer d’Elementer vun der Websäit uginn...',
	'texte_referencement_automatique' => '<b>Automatescht Verlinke vun enger Websäit</b><br />Dir kënnt eng Websäit séier verlinken an dem der hei d’URL oder d’Adress vun sengem Syndicatiouns-Fichier agitt. SPIP kritt dann automatesch d’Informatiounen (Titel, Beschreiwung...).',
	'texte_referencement_automatique_verifier' => 'Kontrolléiert d’Informatiounen déi vun <tt>@url@</tt> koum sinn ier dër späichert.',
	'texte_syndication' => 'Et ass méiglech, wann eng Websäit dat erlaabt, automatesch d’Lëscht vun senge Neiegkeeten ze kréien. Schalt duerfir d’Syndicatioun an.<blockquote><i>Verschidde Hosting-Provideren verhënneren dës Prozedur; an deem Fall kënnt dir d’Syndicatioun net benotzen.</i></blockquote>',
	'titre_articles_syndiques' => 'Syndicéiert Artikelen vun dëser Websäit',
	'titre_dernier_article_syndique' => 'Läscht syndicéiert Artikelen',
	'titre_exporter_bookmarks' => 'Bookmarks exportéieren',
	'titre_importer_bookmarks' => 'Bookmarks importéieren',
	'titre_importer_exporter_bookmarks' => 'Bookmarks importéieren oder exportéieren',
	'titre_page_sites_tous' => 'Déi verlinkte Websäiten',
	'titre_referencement_sites' => 'Websäite verlinken a syndicéieren',
	'titre_site_numero' => 'WEBSÄIT NUMMER:',
	'titre_sites_proposes' => 'Virgeschloe Websäiten',
	'titre_sites_references_rubrique' => 'Verlinkte Websäiten an dëser Rubrik',
	'titre_sites_syndiques' => 'Syndicéiert Websäiten',
	'titre_sites_tous' => 'Déi verlinkte Websäiten',
	'titre_syndication' => 'Syndicatioun vun de Websäiten',
	'tout_voir' => 'All déi syndicéiert Artikele weisen',

	// U
	'un_article_syndic' => '1 syndicéierten Artikel',
];
